]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Improved painting of cursor values
[pulseview.git] / main.cpp
index 54a69fd75550eb3485861bd471d27f6e2d6497a7..9e8bfc7f9c83313510ca8b186102ecc4297f66c3 100644 (file)
--- a/main.cpp
+++ b/main.cpp
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-extern "C" {
 #include <sigrokdecode.h> /* First, so we avoid a _POSIX_C_SOURCE warning. */
 #include <signal.h>
 #include <stdint.h>
 #include <libsigrok/libsigrok.h>
-}
 
 #include <getopt.h>
 
@@ -36,11 +34,12 @@ extern "C" {
 
 // Global pointer to our QApplication
 QApplication *g_app = NULL;
+
 void usage()
 {
-       fprintf(stderr,
+       fprintf(stdout,
                "Usage:\n"
-               "  %s — %s\n"
+               "  %s [OPTION…] [FILE] — %s\n"
                "\n"
                "Help Options:\n"
                "  -V, --version                   Show release version\n"
@@ -49,13 +48,13 @@ void usage()
 }
 
 /*
* SIGINT handler (likely recieved Ctrl-C from terminal)
  */
-void sigint(int param)
+void sigint_handler(int param)
 {
-       (void) param;
+       (void)param;
 
-       qDebug("pv: Recieved SIGINT");
+       qDebug("Received SIGINT.");
 
        if (g_app)
                g_app->quit();
@@ -65,9 +64,10 @@ int main(int argc, char *argv[])
 {
        int ret = 0;
        struct sr_context *sr_ctx = NULL;
+       const char *open_file = NULL;
 
        // Register a SIGINT handler
-       signal (SIGINT, sigint);
+       signal(SIGINT, sigint_handler);
 
        QApplication a(argc, argv);
        // Now we have an application to populate our global pointer
@@ -86,7 +86,7 @@ int main(int argc, char *argv[])
                        {0, 0, 0, 0}
                };
 
-               const char c = getopt_long(argc, argv,
+               const int c = getopt_long(argc, argv,
                        "Vh?", long_options, NULL);
                if (c == -1)
                        break;
@@ -94,7 +94,7 @@ int main(int argc, char *argv[])
                switch (c) {
                case 'V':
                        // Print version info
-                       fprintf(stderr, "%s %s\n", PV_TITLE, PV_VERSION_STRING);
+                       fprintf(stdout, "%s %s\n", PV_TITLE, PV_VERSION_STRING);
                        return 0;
 
                case 'h':
@@ -104,6 +104,12 @@ int main(int argc, char *argv[])
                }
        }
 
+       if (argc - optind > 1) {
+               fprintf(stderr, "Only one file can be openened.\n");
+               return 1;
+       } else if (argc - optind == 1)
+               open_file = argv[argc - 1];
+
        // Initialise libsigrok
        if (sr_init(&sr_ctx) != SR_OK) {
                qDebug() << "ERROR: libsigrok init failed.";
@@ -129,7 +135,7 @@ int main(int argc, char *argv[])
 
                if (ret == 0) {
                        // Initialise the main window
-                       pv::MainWindow w;
+                       pv::MainWindow w(open_file);
                        w.show();
 
                        // Run the application
@@ -49,13 +48,13 @@ void usage()
 
 /*
- * SIGINT handler (likely recieved Ctrl-C from terminal)
+ * SIGINT handler (likely received Ctrl-C from terminal)
  */